==> theme-bootstrap-1.0.121.tgz: package/src/components/refill-balance/calc-amount/calc-amount.jsx <==
import React, { Component } from 'react';
import PropTypes from 'prop-types';
import { FormattedMessage } from 'react-intl';

import Button from 'reactstrap/lib/Button';
import Label from 'reactstrap/lib/Label';
import FormGroup from 'reactstrap/lib/FormGroup';
import Input from 'reactstrap/lib/Input';

import { IconEth } from '../../icons/icon-eth/icon-eth';
import { IconScr } from '../../icons/icon-scr/icon-scr';
import { IconDotPreloader } from '../../icons/icon-dot-preloader/icon-dot-preloader';
import { InputWithIcon } from '../../form/input-with-icon/input-with-icon';

import { CHAR_CODES } from '../../../constants';

import GA from '../../../helpers/ga';

import './calc-amount.scss';

export class CalcAmount extends Component {
  static propTypes = {
    rate: PropTypes.string,
    ethValue: PropTypes.string,
    scrValue: PropTypes.string,
    maxAmount: PropTypes.string,
    ethErrorMsg: PropTypes.string,
    scrErrorMsg: PropTypes.string,
    onEthChange: PropTypes.func.isRequired,
    onScrChange: PropTypes.func.isRequired,
    isEthLoading: PropTypes.bool,
    isScrLoading: PropTypes.bool,
    onContinueClick: PropTypes.func.isRequired,
    isMaxAmountLoading: PropTypes.bool,
  };

  static defaultProps = {
    rate: null,
    ethValue: '',
    scrValue: '',
    maxAmount: null,
    ethErrorMsg: '',
    scrErrorMsg: '',
    isEthLoading: false,
    isScrLoading: false,
    isMaxAmountLoading: false,
  };

  state = {
    checked: true,
  };

  checkValidAmountValue = amount => /^\d+.?\d{0,9}$/.test(amount) && !/^0\d/.test(amount);

  onKeyPress = (evt) => {
    const { which, keyCode } = evt;
    const charCode = which || keyCode;
    if ((charCode > CHAR_CODES.CONTROL &&
      ((charCode < CHAR_CODES.ZERO && charCode !== CHAR_CODES.DOT)
      || charCode > CHAR_CODES.NINE))
    ) {
      evt.preventDefault();
    }
  }

  ethChangeHandler = (e) => {
    const { value } = e.target;

    if (value.length && !this.checkValidAmountValue(value)) {
      return;
    }

    this.props.onEthChange(value);
  }

  scrChangeHandler = (e) => {
    const { value } = e.target;

    if (value.length && !this.checkValidAmountValue(value)) {
      return;
    }

    this.props.onScrChange(value);
  }

  toggleCheck = () => this.setState(prevState => ({ checked: !prevState.checked }));

  onContinueClick = () => {
    GA.event({ category: 'BuySCR', action: '3Calc step continue' });
    this.props.onContinueClick();
  }

  render() {
    const { checked } = this.state;
    const {
      ethValue, scrValue, rate, maxAmount, ethErrorMsg, scrErrorMsg, isEthLoading, isScrLoading, isMaxAmountLoading,
    } = this.props;

    return (
      <div className="calc-amount-step">
        <h3 className="text-center mb-4">
          <FormattedMessage id="universal.balance.refill.calc-step.title" />
        </h3>

        <div className="d-flex mb-4">
          <InputWithIcon
            icon={<IconEth />}
            value={ethValue}
            errorMsg={ethErrorMsg}
            onChange={this.ethChangeHandler}
            isLoading={isEthLoading}
            onKeyPress={this.onKeyPress}
          />
          <h5 className="mx-1_5 pt-2 text-gray-dark-hint">=</h5>
          <InputWithIcon
            icon={<IconScr />}
            value={scrValue}
            errorMsg={scrErrorMsg}
            onChange={this.scrChangeHandler}
            isLoading={isScrLoading}
            onKeyPress={this.onKeyPress}
          />
        </div>

        <div className="d-flex justify-content-between">
          <span className="text-gray-dark-hint">
            <FormattedMessage id="universal.balance.refill.calc-step.rate" />
          </span>
          {!rate && (isEthLoading || isScrLoading) ? <IconDotPreloader className="h5p dot-preloader-small" />
            : (
              <span className="h5p ml-1 text-nowrap">
                1 SCR = {rate} ETH
              </span>
          )}
        </div>

        <div className="divider my-2" />

        <div className="d-flex justify-content-between">
          <span className="text-gray-dark-hint">
            <FormattedMessage id="universal.balance.refill.calc-step.max.title" />
          </span>
          {isMaxAmountLoading ? <IconDotPreloader className="h5p dot-preloader-small" />
          : (
            <span className="h5p ml-1 text-nowrap">
              <FormattedMessage id="universal.balance.refill.calc-step.max.value" values={{ value: maxAmount }} />
            </span>
          )}
        </div>

        <div className="mt-3_5 mb-4 p-1_5 text-small text-gray-dark-secondary bg-shade-s20">
          <FormattedMessage id="universal.balance.refill.calc-step.description" />
        </div>

        <Button color="primary" block className="mb-2" disabled={!checked} onClick={this.onContinueClick}>
          <FormattedMessage id="universal.continue" />
        </Button>

        <FormGroup check>
          <Label check>
            <Input type="checkbox" checked={checked} onChange={this.toggleCheck} />
            <span className="text-gray-dark-secondary">
              <FormattedMessage id="universal.balance.refill.calc-step.checkbox" />
            </span>
          </Label>
        </FormGroup>
      </div>
    );
  }
}

==> theme-bootstrap-2.0.12.tgz: package/src/components/refill-balance/calc-amount/calc-amount.jsx <==
import React, { Component } from 'react';
import PropTypes from 'prop-types';
import { FormattedMessage } from 'react-intl';

import Button from 'reactstrap/lib/Button';
import Label from 'reactstrap/lib/Label';
import FormGroup from 'reactstrap/lib/FormGroup';
import Input from 'reactstrap/lib/Input';

import { IconEth } from '../../icons/icon-eth/icon-eth';
import { IconScr } from '../../icons/icon-scr/icon-scr';
import { IconDotPreloader } from '../../icons/icon-dot-preloader/icon-dot-preloader';
import { InputWithIcon } from '../../form/input-with-icon/input-with-icon';

import { CHAR_CODES } from '../../../constants';

import GA from '../../../helpers/ga';

import './calc-amount.scss';

export class CalcAmount extends Component {
  static propTypes = {
    rate: PropTypes.string,
    ethValue: PropTypes.string,
    scrValue: PropTypes.string,
    maxAmount: PropTypes.string,
    ethErrorMsg: PropTypes.string,
    scrErrorMsg: PropTypes.string,
    onEthChange: PropTypes.func.isRequired,
    onScrChange: PropTypes.func.isRequired,
    ethFraction: PropTypes.number.isRequired,
    scrFraction: PropTypes.number.isRequired,
    isEthLoading: PropTypes.bool,
    isScrLoading: PropTypes.bool,
    onContinueClick: PropTypes.func.isRequired,
    isMaxAmountLoading: PropTypes.bool,
  };

  static defaultProps = {
    rate: null,
    ethValue: '',
    scrValue: '',
    maxAmount: null,
    ethErrorMsg: '',
    scrErrorMsg: '',
    isEthLoading: false,
    isScrLoading: false,
    isMaxAmountLoading: false,
  };

  state = {
    checked: true,
  };

  checkValidAmountValue = (amount, max) => {
    // eslint-disable-next-line
    const re = new RegExp('^\\d+\.?\\d{0,'+ max +'}$');

    return re.test(amount) && !/^0\d/.test(amount);
  }

  onKeyPress = (evt) => {
    const { which, keyCode } = evt;
    const charCode = which || keyCode;
    if ((charCode > CHAR_CODES.CONTROL &&
      ((charCode < CHAR_CODES.ZERO && charCode !== CHAR_CODES.DOT)
      || charCode > CHAR_CODES.NINE))
    ) {
      evt.preventDefault();
    }
  }

  ethChangeHandler = (e) => {
    const { value } = e.target;

    if (value.length && !this.checkValidAmountValue(value, this.props.ethFraction)) {
      return;
    }

    this.props.onEthChange(value);
  }

  scrChangeHandler = (e) => {
    const { value } = e.target;

    if (value.length && !this.checkValidAmountValue(value, this.props.scrFraction)) {
      return;
    }

    this.props.onScrChange(value);
  }

  toggleCheck = () => this.setState(prevState => ({ checked: !prevState.checked }));

  onContinueClick = () => {
    GA.event({ category: 'BuySCR', action: '3Calc step continue' });
    this.props.onContinueClick();
  }

  render() {
    const { checked } = this.state;
    const {
      ethValue, scrValue, rate, maxAmount, ethErrorMsg, scrErrorMsg, isEthLoading, isScrLoading, isMaxAmountLoading,
    } = this.props;

    return (
      <div className="calc-amount-step">
        <h3 className="text-center mb-4">
          <FormattedMessage id="universal.balance.refill.calc-step.title" />
        </h3>

        <div className="d-flex mb-4">
          <InputWithIcon
            icon={<IconEth />}
            value={ethValue}
            errorMsg={ethErrorMsg}
            onChange={this.ethChangeHandler}
            isLoading={isEthLoading}
            onKeyPress={this.onKeyPress}
          />
          <h5 className="mx-1_5 pt-2 text-gray-dark-hint">=</h5>
          <InputWithIcon
            icon={<IconScr />}
            value={scrValue}
            errorMsg={scrErrorMsg}
            onChange={this.scrChangeHandler}
            isLoading={isScrLoading}
            onKeyPress={this.onKeyPress}
          />
        </div>

        <div className="d-flex justify-content-between">
          <span className="text-gray-dark-hint">
            <FormattedMessage id="universal.balance.refill.calc-step.rate" />
          </span>
          {!rate && (isEthLoading || isScrLoading) ? <IconDotPreloader className="h5p dot-preloader-small" />
            : (
              <span className="h5p ml-1 text-nowrap">
                1 SCR = {rate} ETH
              </span>
          )}
        </div>

        <div className="divider my-2" />

        <div className="d-flex justify-content-between">
          <span className="text-gray-dark-hint">
            <FormattedMessage id="universal.balance.refill.calc-step.max.title" />
          </span>
          {isMaxAmountLoading ? <IconDotPreloader className="h5p dot-preloader-small" />
          : (
            <span className="h5p ml-1 text-nowrap">
              <FormattedMessage id="universal.balance.refill.calc-step.max.value" values={{ value: maxAmount }} />
            </span>
          )}
        </div>

        <div className="mt-3_5 mb-4 p-1_5 text-small text-gray-dark-secondary bg-shade-s20">
          <FormattedMessage id="universal.balance.refill.calc-step.description" />
        </div>

        <Button color="primary" block className="mb-2" disabled={!checked} onClick={this.onContinueClick}>
          <FormattedMessage id="universal.continue" />
        </Button>

        <FormGroup check>
          <Label check>
            <Input type="checkbox" checked={checked} onChange={this.toggleCheck} />
            <span className="text-gray-dark-secondary">
              <FormattedMessage id="universal.balance.refill.calc-step.checkbox" />
            </span>
          </Label>
        </FormGroup>
      </div>
    );
  }
}
